@@ -1,6 +1,6 @@
 from pygments.lexer import RegexLexer, DelegatingLexer, bygroups
 from pygments.lexers import RubyLexer
-from pygments.token import Text, Other, Keyword
+from pygments.token import Text, Other, Keyword, Number
 
 class PryPrefixLexer(RegexLexer):
     """
